==> db4o_6.1.401~dfsg.orig.tar.gz: db4o-6.1/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Assorted/AllTests.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Tests.Common.Assorted
{
	public class AllTests : Db4oUnit.Extensions.Db4oTestSuite
	{
		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Assorted.AllTests().RunSolo();
		}

		protected override System.Type[] TestCases()
		{
			return new System.Type[] { typeof(Db4objects.Db4o.Tests.Common.Assorted.AliasesTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.BackupStressTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.CanUpdateFalseRefreshTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.CascadedDeleteReaddTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.ChangeIdentity)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ClassMetadataTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.CloseUnlocksFileTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ComparatorSortTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.DatabaseUnicityTest)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.DescendToNullFieldTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.FileSizeOnRollbackTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.GetByUUIDTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.GetSingleSimpleArrayTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.HandlerRegistryTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.IndexCreateDropTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.LongLinkedListTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.MultiDeleteTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.NakedObjectTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.ObjectMarshallerTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ObjectVersionTest), typeof(Db4objects.Db4o.Tests.Common.Assorted.PersistStaticFieldValuesTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.PersistTypeTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.PreventMultipleOpenTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ReAddCascadedDeleteTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.ReferenceSystemTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.RollbackTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.SimplestPossibleTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ServerRevokeAccessTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.SystemInfoTestCase)
				 };
		}
	}
}

==> db4o_6.1.604+dfsg.orig.tar.gz: db4o-6.1.604/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Assorted/AllTests.cs <==
/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Tests.Common.Assorted
{
	public class AllTests : Db4oUnit.Extensions.Db4oTestSuite
	{
		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Assorted.AllTests().RunSolo();
		}

		protected override System.Type[] TestCases()
		{
			return new System.Type[] { typeof(Db4objects.Db4o.Tests.Common.Assorted.AliasesTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.BackupStressTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.CanUpdateFalseRefreshTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.CascadedDeleteReaddTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.ChangeIdentity)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ClassMetadataTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.CloseUnlocksFileTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ComparatorSortTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.DatabaseUnicityTest)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.DescendToNullFieldTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.FileIncompatibleExceptionTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.FileSizeOnRollbackTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.GetByUUIDTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.GetSingleSimpleArrayTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.HandlerRegistryTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.IndexCreateDropTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.LongLinkedListTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.MultiDeleteTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.NakedObjectTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ObjectMarshallerTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.PersistStaticFieldValuesTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.PersistTypeTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.PreventMultipleOpenTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ReAddCascadedDeleteTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.ReferenceSystemTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.RollbackTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.SimplestPossibleTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Assorted.ServerRevokeAccessTestCase), typeof(Db4objects.Db4o.Tests.Common.Assorted.SystemInfoTestCase)
				 };
		}
	}
}
